@@ -1,6 +1,6 @@
 from .connector import EscriptoriumConnector
 
-from .copy_document import (
+from .convenience_functions import (
     copy_documents,
     copy_documents_monitored,
     copy_documents_generator,
