@@ -24,13 +24,29 @@ class PostTranscription:
     graphs: Union[str, None] = None
 
 
+@dataclass(init=True, frozen=True)
+class GetVersionData:
+    graphs: Union[None, List[List[int]]]
+    content: str
+
+
+@dataclass(init=True, frozen=True)
+class GetVersion:
+    data: GetVersionData
+    author: str
+    source: str
+    revision: str
+    created_at: datetime
+    updated_at: datetime
+
+
 @dataclass(init=True, frozen=True)
 class GetTranscription:
     pk: int
     line: int
     transcription: int
     content: str
-    versions: List[str]  # TODO: Check that this is correct
+    versions: List[GetVersion]
     version_author: str
     version_source: str
     version_updated_at: datetime
